sdss-access Reference
=========================

.. _api-sdss-access:

Path
----

.. automodule:: sdss_access.path.path
   :members:
   :undoc-members:
   :show-inheritance:

Sync
----

Auth
^^^^
.. automodule:: sdss_access.sync.auth
   :members:
   :undoc-members:
   :show-inheritance:

Client
^^^^^^
.. automodule:: sdss_access.sync.cli
   :members:
   :undoc-members:
   :show-inheritance:

Http
^^^^
.. automodule:: sdss_access.sync.http
   :members:
   :undoc-members:
   :show-inheritance:

Rsync
^^^^^
.. automodule:: sdss_access.sync.rsync
   :members:
   :undoc-members:
   :show-inheritance:

Stream
^^^^^^
.. automodule:: sdss_access.sync.stream
   :members:
   :undoc-members:
   :show-inheritance:

System Call
^^^^^^^^^^^
.. automodule:: sdss_access.sync.system_call
   :members:
   :undoc-members:
   :show-inheritance:


